authj

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2020 License: MIT Imports: 3 Imported by: 0

README

authj

GoDoc Build Status codecov Action Status Go Report Card Licence

authj is an authorization middleware for Gin, it's based on casbin.

Installation

go get github.com/thinkgos/authj

Simple Example

package main

import (
    "net/http"

    "github.com/casbin/casbin/v2"
    "github.com/thinkgos/authj"
    "github.com/gin-gonic/gin"
)

func main() {
    // load the casbin model and policy from files, database is also supported.
    e ,err := casbin.NewEnforcer("authz_model.conf", "authz_policy.csv")
    if err!= nil{
        panic(err)    
    }   

    // define your router, and use the Casbin authj middleware.
    // the access that is denied by authj will return HTTP 403 error.
    router := gin.New()
    router.Use(authj.NewAuthorizer(e, authj.Subject(func(c *gin.Context) string {
        // return subject like username
        return "admin"
    })))
}

Documentation

The authorization determines a request based on {subject, object, action}, which means what subject can perform what action on what object. In this plugin, the meanings are:

  1. subject: the logged-on user name
  2. object: the URL path for the web resource like "dataset1/item1"
  3. action: HTTP method like GET, POST, PUT, DELETE, or the high-level actions you defined like "read-file", "write-blog"

For how to write authorization policy and other details, please refer to the Casbin's documentation.

Getting Help

License

This project is under MIT License. See the LICENSE file for the full license text.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewAuthorizer

func NewAuthorizer(e *casbin.Enforcer, s Subject) gin.HandlerFunc

NewAuthorizer returns the authorizer uses a Casbin enforcer and Subject function as input

Types

type Subject

type Subject func(c *gin.Context) string

Subject function get subject

Jump to