authj

authj is an authorization middleware for Gin, it's based on
casbin.
Installation
go get github.com/thinkgos/authj
Simple Example
package main
import (
"net/http"
"github.com/casbin/casbin/v2"
"github.com/thinkgos/authj"
"github.com/gin-gonic/gin"
)
func main() {
// load the casbin model and policy from files, database is also supported.
e ,err := casbin.NewEnforcer("authz_model.conf", "authz_policy.csv")
if err!= nil{
panic(err)
}
// define your router, and use the Casbin authj middleware.
// the access that is denied by authj will return HTTP 403 error.
router := gin.New()
router.Use(authj.NewAuthorizer(e, authj.Subject(func(c *gin.Context) string {
// return subject like username
return "admin"
})))
}
Documentation
The authorization determines a request based on {subject, object, action}, which means what subject can perform what action on what object. In this plugin, the meanings are:
subject: the logged-on user name
object: the URL path for the web resource like "dataset1/item1"
action: HTTP method like GET, POST, PUT, DELETE, or the high-level actions you defined like "read-file", "write-blog"
For how to write authorization policy and other details, please refer to the Casbin's documentation.
Getting Help
License
This project is under MIT License. See the LICENSE file for the full license text.